from setuptools import setup, find_packages
setup(
    name='sbmy_control',
    version='0.1.0',
    author='Mayeul Aubin',
    author_email='mayeul.aubin@iap.fr',
    description='Simbelmyne control package',
    long_description='This package provides control functionalities for Simbelmyne. It allows to create automatically all the required files and scripts to run a N-body simulation with Simbelmyne, using monofonIC for initial conditions. The subpackage `analysis` provides tools to analyze the results of the simulation (slices and power spectra), while the subpackage `scripts` includes tools to handle snapshots, tiles and density fields.',
    long_description_content_type='text/markdown',
    url='https://git.aquila-consortium.org/maubin/sbmy_control',
    packages=find_packages(),
    install_requires=[
        'pysbmy',
        'numpy',
        'matplotlib',
        'h5py',
        'tqdm',
    ],
    license='GPL-3.0',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
    ],
    python_requires='>=3.8',
    entry_points={
        'console_scripts': [
            'sbmy_control=sbmy_control.main:console_main',
            'slices=sbmy_control.analysis.slices:console_main',
            'power_spectrum=sbmy_control.analysis.power_spectrum:console_main',
            'field_to_field=sbmy_control.scripts.field_to_field:console_main',
            'gather_tiles=sbmy_control.scripts.gather_tiles:console_main',
            'convert_snapshot_to_density=sbmy_control.scripts.convert_snapshot_to_density:console_main',
            'scola_submit=sbmy_control.scripts.scola_submit:console_main',
        ],
    },
)